==> kmymoney2_0.8.9.orig.tar.gz: kmymoney2-0.8.9.orig/kmymoney2/plugins/interfaces/kmmstatementinterface.h <==
/***************************************************************************
                          kmmstatementinterface.h
                             -------------------
    begin                : Wed Jan 5 2005
    copyright            : (C) 2005 Thomas Baumgart
    email                : ipwizard@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMMSTATEMENTINTERFACE_H
#define KMMSTATEMENTINTERFACE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// ----------------------------------------------------------------------------
// QT Includes

// ----------------------------------------------------------------------------
// KDE Includes

// ----------------------------------------------------------------------------
// Project Includes

class KMyMoney2App;
#include "../statementinterface.h"

namespace KMyMoneyPlugin {

/**
  * This class represents the implementation of the
  * StatementInterface.
  */
class KMMStatementInterface : public StatementInterface
{
  Q_OBJECT

public:
  KMMStatementInterface(KMyMoney2App* app, QObject* parent, const char* name = 0);
  ~KMMStatementInterface() {};

  /**
    * This method imports a MyMoneyStatement into the engine
    */
  bool import(MyMoneyStatement& s);

private:
  KMyMoney2App*    m_app;
};

}; // namespace
#endif

==> kmymoney2_0.9.2.orig.tar.gz: kmymoney2-0.9.2/kmymoney2/plugins/interfaces/kmmstatementinterface.h <==
/***************************************************************************
                          kmmstatementinterface.h
                             -------------------
    begin                : Wed Jan 5 2005
    copyright            : (C) 2005 Thomas Baumgart
    email                : ipwizard@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMMSTATEMENTINTERFACE_H
#define KMMSTATEMENTINTERFACE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// ----------------------------------------------------------------------------
// QT Includes

// ----------------------------------------------------------------------------
// KDE Includes

// ----------------------------------------------------------------------------
// Project Includes

class KMyMoney2App;
class MyMoneyAccount;
class MyMoneyKeyValueContainer;

#include "../statementinterface.h"

namespace KMyMoneyPlugin {

/**
  * This class represents the implementation of the
  * StatementInterface.
  */
class KMMStatementInterface : public StatementInterface
{
  Q_OBJECT

public:
  KMMStatementInterface(KMyMoney2App* app, QObject* parent, const char* name = 0);
  ~KMMStatementInterface() {}

  /**
    * This method imports a MyMoneyStatement into the engine
    */
  bool import(const MyMoneyStatement& s);

  /**
   * This method returns the account for a given @a key - @a value pair.
   * If the account is not found in the list of accounts, MyMoneyAccount()
   * is returned.
   */
  const MyMoneyAccount& account(const QString& key, const QString& value) const;

  /**
   * This method stores the online parameters in @kvps used by the plugin
   * with the account @a acc.
   */
  void setAccountOnlineParameters(const MyMoneyAccount&acc, const MyMoneyKeyValueContainer& kvps) const;

private:
  KMyMoney2App*    m_app;
};

}; // namespace
#endif
